numpy.format_parser
===================

.. currentmodule:: numpy

.. autoclass:: format_parser

   

   .. HACK
      .. autosummary::
         :toctree:
      
         format_parser.__init__



   

